const {
  Scene,
  Object3D,
  PerspectiveCamera,
  WebGLRenderer,
  CanvasTexture,
  Sprite,
  SpriteMaterial,
  loadTexture,
  ImageUtils,
  PointLight,
  SpriteAlignment,
  shadowMap,
  BufferGeometry,
  BufferGeometryUtils,
  CubeTextureLoader,
  MultiMaterial,
  Raycaster,
  Vector2,
  Vector3,
  vertices
} = THREE 

import {TerrainGenerator} from './TerrainGenerator.js';
import { getData } from './getData';
import { Enum } from './Texture.js';
import fragmentShader from './fragmentShader';
import vertexShader from './vertexShader';
import {PieSprite, spriteTexture} from './PieSprite';
import {WoWZonesPosition, crtZonesSprites, textureUpdate, ZonesToSprites} from './PieSpritesPos';
import {targetList, onDocumentMouseOver} from './Intersect';


const run = async () => {
  return await getData()
};
run();

// Tweakables
const scaleFactor = 5; // HiDPI
const width = window.innerWidth * scaleFactor;

const height = window.innerHeight * scaleFactor;
const rotationSensitivity = 0.04;
const rotationIncrement = -0.2;

console.log(window.innerWidth,window.innerHeight )

// Returns a color for a given datum and number of clusters.
export const camera = new PerspectiveCamera(20, width / height, 1, 100000);
const renderer = new WebGLRenderer({ antialias: true, alpha: false
                                   });

renderer.setSize(width, height);
document.body.appendChild(renderer.domElement);
renderer.domElement.style.width = width / scaleFactor + 'px';
renderer.domElement.style.height = height / scaleFactor + 'px';




var controls = new THREE.OrbitControls(camera, renderer.domElement);

const scene = new Scene();

console.log(renderer.info);
renderer.info.autoReset = false;
renderer.info.reset();

//GROUND
const groundWidth = 10;
const groundHeight = 10;
var groundTexture = new THREE.TextureLoader().load(
  'https://raw.githubusercontent.com/stemkoski/stemkoski.github.com/master/Three.js/images/checkerboard.jpg'
);
groundTexture.wrapS = groundTexture.wrapT = THREE.RepeatWrapping;
groundTexture.repeat.set(groundWidth/4, groundHeight/4);
var groundMaterial = new THREE.MeshBasicMaterial({
  map: groundTexture,
  side: THREE.DoubleSide
});
var groundGeometry = new THREE.PlaneGeometry(groundWidth, groundHeight);
var ground = new THREE.Mesh(groundGeometry, groundMaterial);
scene.add(ground);



const csvUrl = 'https://github.com/meperezcuello/dataviz-project-template-proposal/blob/master/azeroth_31_26_heighmap.png';
const csvUrl2 = 'https://gist.githubusercontent.com/meperezcuello/eb1f6c7dabe63443aa1dafa169e51d07/raw/1c7e70db4548e8ce7eaf9c9ba21391681462651c/mountain.csv'
//** Custom Texture Mapping **//

let dict = [
    {texture:'oceanTexture', repeatedness: 5, smoothing: [0.01, 0.50]}, //<-- this is bottom texture
    {texture:'sandyTexture', repeatedness: 20, smoothing: [0.50, 0.55]},
    {texture:'snowyTexture', repeatedness: 20, smoothing: [0.55, 0.65]},
    {texture:'snowyTexture', repeatedness: 10, smoothing: [0.65, 0.75]},
    {texture:'snowyTexture', repeatedness: 20, smoothing: [0.75, 0.99]}, // <-- this is top texture
  ];

let wow = [
    {texture:'wowtest', repeatedness: 1, smoothing: [0.01, 0.01]}, //<-- this is bottom texture
  ];
  

const TerrainMain = async() => {
  
  const terrain =  new TerrainGenerator(csvUrl,[],'https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/Azeroth_heigthmao.png')
  terrain.loadMaterials(wow);
  return await terrain.mesh()
  
}
//https://raw.githubusercontent.com/meperezcuello/dataviz-project-template-proposal/master/heigmaps_testing_2.png


(async() => {
  const mesh = await TerrainMain();

  console.log(mesh)
   mesh.rotation.x = -Math.PI / 2;
   mesh.position.y = 0;
 	scene.add(mesh);
  
	console.log(mesh)
  
    var controls2 = new function() {
            this.rotationSpeed = 1;
            this.bouncingSpeed = 0.03;
        }
    


 

        //gui.add(controls2, 'bouncingSpeed',0,0.5);
	//console.log(teext(scene));
 
  
  //let texture2 = spriteTexture();
  //teext(scene)

 

	console.log(textureUpdate())
  console.log(crtZonesSprites())
  const waterCube = new THREE.PlaneBufferGeometry(1000, 616, 1);
  
  const water = new THREE.Mesh(waterCube, new THREE.MeshBasicMaterial({color:0x001d28, transparent: true, opacity: 0.80, side: THREE.DoubleSide}));
 	scene.add(water);
water.rotation.x = -Math.PI / 2;
water.position.y = 27.2;
//water.receiveShadow = true;



  
  
//LIGHT
  const light = new THREE.PointLight(0xffffff, 2, 350);
  light.position.set(105, 100, 15);
  light.castShadow = true;
  light.shadow.camera.near = 0.3;
  light.shadow.camera.far = 25;
  scene.add(light);



//Init ground roration
const epsilon = -0.5;
ground.rotation.x -= Math.PI / 2;
ground.position.z = groundWidth/2 + epsilon;
ground.position.x = groundHeight/2 + epsilon;
ground.position.y = epsilon;


var axesHelper = new THREE.AxesHelper( 100 );
scene.add( axesHelper );
//Init camera position
//camera.rotation.x = Math.PI/2;
camera.position.set(300, 800, -800);


var raycaster = new Raycaster();
var mouse = new Vector2();

let targetList = [];
targetList.push(mesh);
  
function onDocumentMouseOver(event) {

	// calculate mouse position in normalized device coordinates
	// (-1 to +1) for both components

	mouse.x = ( event.clientX / window.innerWidth ) * 2 - 1;
	mouse.y = - ( event.clientY / window.innerHeight ) * 2 + 1;

  //var vector_2 = new Vector3( mouse.x, mouse.y, 1 ); 
  
  raycaster.setFromCamera( mouse, camera );

	// calculate objects intersecting the picking ray
	var intersects = raycaster.intersectObjects( targetList );
	console.log(intersects[0])
  if ( intersects[0]){
    console.log(intersects[0].point)
      //intersects[0].face.color.setRGB( Math.random()*255,Math.random()*255, Math.random()*255);
      //intersects[0].face.color.needsUpdate = true;
    }
}
  
  let lol = false; 
  function fn() {
      lol = true;
    }
  
 
  
 //window.addEventListener( 'mousedown', fn, false ); 
  
	const gui = new dat.GUI();
  
  const parameters = 
	{
		Hour: 0
	};
  
  let folder1 = gui.addFolder('Accumulative Hours');
  let cubeX = folder1.add( parameters, 'Hour' ).min(0).max(100).step(1).listen();
  	folder1.open();
   cubeX.onFinishChange(function(value) {
  // Fires when a controller loses focus.
    lol = true;
  });
  
	let yey = 0 
	//window['scene'] = scene; 
  //window['yey'] = yey; 
   //window.eval(crtZonesSprites())
    	let texture_0=spriteTexture('Durotar', yey); PieSprite(scene, texture_0,30,-277.78955311352763,24,38.67265811035771);let texture_1=spriteTexture('Azshara', yey); PieSprite(scene, texture_1,30,-236.90184905507408,24,-18.04310167920776);let texture_2=spriteTexture('Northen Barrens', yey); PieSprite(scene, texture_2,30,-324.3342548486014,24,42.40533222353124);let texture_3=spriteTexture('Southern Barrens', yey); PieSprite(scene, texture_3,30,-329.55571944397286,24,77.34899932128461);let texture_4=spriteTexture('Mulgore', yey); PieSprite(scene, texture_4,30,-360.32731675044806,24,79.35111158362415);let texture_5=spriteTexture('Ashenvale', yey); PieSprite(scene, texture_5,30,-343.5705344278353,24,6.189150329805115);let texture_6=spriteTexture('Felwood', yey); PieSprite(scene, texture_6,30,-350.66999035361914,44,-64.92611869671175);let texture_7=spriteTexture('Darkshore', yey); PieSprite(scene, texture_7,30,-385.31446419961196,24,-76.68302114072709);let texture_8=spriteTexture('Winterspring', yey); PieSprite(scene, texture_8,30,-284.57397200584023,54,-81.47558729825629);let texture_9=spriteTexture('Moonglade', yey); PieSprite(scene, texture_9,30,-321.13909336551916,48,-97.74738874506933);let texture_10=spriteTexture('Teldrassil', yey); PieSprite(scene, texture_10,30,-402.9094076156481,78,-131.7407672265867);let texture_11=spriteTexture('Mount Hyjal', yey); PieSprite(scene, texture_11,30,-307.3388799075823,94,-47.834504859241434);let texture_12=spriteTexture('Stonetalon Mountains', yey); PieSprite(scene, texture_12,30,-399.0184945319111,30,20.7443401431147);let texture_13=spriteTexture('Desolace', yey); PieSprite(scene, texture_13,30,-399.5848529640793,24,64.0883236559438);let texture_14=spriteTexture('Dustwallow Marsh', yey); PieSprite(scene, texture_14,30,-287.0818159107408,24,120.27639521544074);let texture_15=spriteTexture('Thousand Needles', yey); PieSprite(scene, texture_15,30,-289.78409117229796,30,157.76589871394427);let texture_16=spriteTexture('Feralas', yey); PieSprite(scene, texture_16,30,-410.16130255590474,34,122.75078982610768);let texture_17=spriteTexture('Silithus', yey); PieSprite(scene, texture_17,30,-388.9210583914758,24,180.21265329905296);let texture_18=spriteTexture('UnGoro Crater', yey); PieSprite(scene, texture_18,30,-344.53177754459716,24,176.73378268582215);let texture_19=spriteTexture('Tanaris', yey); PieSprite(scene, texture_19,30,-300.38527277906513,30,200.80222710443277);let texture_20=spriteTexture('Uldum', yey); PieSprite(scene, texture_20,30,-364.4577852044935,38,234.19477795867547);let texture_21=spriteTexture('The Cape of Stranglethorn', yey); PieSprite(scene, texture_21,30,320.40466464778575,24,238.1933703285855);let texture_22=spriteTexture('Northern Stranglethorn', yey); PieSprite(scene, texture_22,30,328.4634388211147,24,204.69122514469524);let texture_23=spriteTexture('Blasted Lands', yey); PieSprite(scene, texture_23,30,391.47520078921195,24,191.7275989959382);let texture_24=spriteTexture('Swamp of Sorrows', yey); PieSprite(scene, texture_24,30,402.0329790005663,24,177.5969478535933);let texture_25=spriteTexture('Duskwood', yey); PieSprite(scene, texture_25,30,336.8137692532394,30,176.69531634588702);let texture_26=spriteTexture('Westfall', yey); PieSprite(scene, texture_26,30,295.8557533417584,24,178.16070679515727);let texture_27=spriteTexture('Redridge Mountains', yey); PieSprite(scene, texture_27,30,386.95887400109643,30,157.47511444858765);let texture_28=spriteTexture('Elwynn Forest', yey); PieSprite(scene, texture_28,30,333.4699859916333,24,164.0337620546048);let texture_29=spriteTexture('Burning Steppes', yey); PieSprite(scene, texture_29,30,363.3163146357488,34,136.76694774590567);let texture_30=spriteTexture('Searing Gorge', yey); PieSprite(scene, texture_30,30,355.61022578427736,34,114.0631759475665);let texture_31=spriteTexture('Badlands', yey); PieSprite(scene, texture_31,30,391.7454864528726,34,111.45380501148495);let texture_32=spriteTexture('Loch Modan', yey); PieSprite(scene, texture_32,30,395.21550049260804,34,82.43017205334165);let texture_33=spriteTexture('Dun Morogh', yey); PieSprite(scene, texture_33,30,337.29679068468414,44,87.79113862904887);let texture_34=spriteTexture('Twilight Highlands', yey); PieSprite(scene, texture_34,30,432.5227454002263,28,60.76836375472595);let texture_35=spriteTexture('Wetlands', yey); PieSprite(scene, texture_35,30,354.934918415537,24,43.181241103898316);let texture_36=spriteTexture('Arathi Highlands', yey); PieSprite(scene, texture_36,30,379.83639451845283,24,13.520356001944405);let texture_37=spriteTexture('The Hinterlands', yey); PieSprite(scene, texture_37,30,391.5695800872891,34,-12.908190028917076);let texture_38=spriteTexture('Hillsbrad Foothills', yey); PieSprite(scene, texture_38,30,345.7407475978628,24,-1.890201373109902);let texture_39=spriteTexture('Gilneas', yey); PieSprite(scene, texture_39,30,296.52793626675634,24,17.84908060196977);let texture_40=spriteTexture('Silverpine Forest', yey); PieSprite(scene, texture_40,30,308.03288950112943,24,-18.1261526897862);let texture_41=spriteTexture('Tirisfal Glades', yey); PieSprite(scene, texture_41,30,322.59503720083575,24,-51.44381451717823);let texture_42=spriteTexture('Western Plaguelands', yey); PieSprite(scene, texture_42,30,357.5636429226708,30,-42.876969500513084);let texture_43=spriteTexture('Eastern Plaguelands', yey); PieSprite(scene, texture_43,30,405.8146279931575,34,-57.98487867077536);

  for ( let yey = 1; yey < 10; yey++ ) {
      texture_0=spriteTexture('Durotar', yey); PieSprite(scene, texture_0,30,-277.78955311352763,24,38.67265811035771);texture_1=spriteTexture('Azshara', yey); PieSprite(scene, texture_1,30,-236.90184905507408,24,-18.04310167920776);texture_2=spriteTexture('Northen Barrens', yey); PieSprite(scene, texture_2,30,-324.3342548486014,24,42.40533222353124);texture_3=spriteTexture('Southern Barrens', yey); PieSprite(scene, texture_3,30,-329.55571944397286,24,77.34899932128461);texture_4=spriteTexture('Mulgore', yey); PieSprite(scene, texture_4,30,-360.32731675044806,24,79.35111158362415);texture_5=spriteTexture('Ashenvale', yey); PieSprite(scene, texture_5,30,-343.5705344278353,24,6.189150329805115);texture_6=spriteTexture('Felwood', yey); PieSprite(scene, texture_6,30,-350.66999035361914,44,-64.92611869671175);texture_7=spriteTexture('Darkshore', yey); PieSprite(scene, texture_7,30,-385.31446419961196,24,-76.68302114072709);texture_8=spriteTexture('Winterspring', yey); PieSprite(scene, texture_8,30,-284.57397200584023,54,-81.47558729825629);texture_9=spriteTexture('Moonglade', yey); PieSprite(scene, texture_9,30,-321.13909336551916,48,-97.74738874506933);texture_10=spriteTexture('Teldrassil', yey); PieSprite(scene, texture_10,30,-402.9094076156481,78,-131.7407672265867);texture_11=spriteTexture('Mount Hyjal', yey); PieSprite(scene, texture_11,30,-307.3388799075823,94,-47.834504859241434);texture_12=spriteTexture('Stonetalon Mountains', yey); PieSprite(scene, texture_12,30,-399.0184945319111,30,20.7443401431147);texture_13=spriteTexture('Desolace', yey); PieSprite(scene, texture_13,30,-399.5848529640793,24,64.0883236559438);texture_14=spriteTexture('Dustwallow Marsh', yey); PieSprite(scene, texture_14,30,-287.0818159107408,24,120.27639521544074);texture_15=spriteTexture('Thousand Needles', yey); PieSprite(scene, texture_15,30,-289.78409117229796,30,157.76589871394427);texture_16=spriteTexture('Feralas', yey); PieSprite(scene, texture_16,30,-410.16130255590474,34,122.75078982610768);texture_17=spriteTexture('Silithus', yey); PieSprite(scene, texture_17,30,-388.9210583914758,24,180.21265329905296);texture_18=spriteTexture('UnGoro Crater', yey); PieSprite(scene, texture_18,30,-344.53177754459716,24,176.73378268582215);texture_19=spriteTexture('Tanaris', yey); PieSprite(scene, texture_19,30,-300.38527277906513,30,200.80222710443277);texture_20=spriteTexture('Uldum', yey); PieSprite(scene, texture_20,30,-364.4577852044935,38,234.19477795867547);texture_21=spriteTexture('The Cape of Stranglethorn', yey); PieSprite(scene, texture_21,30,320.40466464778575,24,238.1933703285855);texture_22=spriteTexture('Northern Stranglethorn', yey); PieSprite(scene, texture_22,30,328.4634388211147,24,204.69122514469524);texture_23=spriteTexture('Blasted Lands', yey); PieSprite(scene, texture_23,30,391.47520078921195,24,191.7275989959382);texture_24=spriteTexture('Swamp of Sorrows', yey); PieSprite(scene, texture_24,30,402.0329790005663,24,177.5969478535933);texture_25=spriteTexture('Duskwood', yey); PieSprite(scene, texture_25,30,336.8137692532394,30,176.69531634588702);texture_26=spriteTexture('Westfall', yey); PieSprite(scene, texture_26,30,295.8557533417584,24,178.16070679515727);texture_27=spriteTexture('Redridge Mountains', yey); PieSprite(scene, texture_27,30,386.95887400109643,30,157.47511444858765);texture_28=spriteTexture('Elwynn Forest', yey); PieSprite(scene, texture_28,30,333.4699859916333,24,164.0337620546048);texture_29=spriteTexture('Burning Steppes', yey); PieSprite(scene, texture_29,30,363.3163146357488,34,136.76694774590567);texture_30=spriteTexture('Searing Gorge', yey); PieSprite(scene, texture_30,30,355.61022578427736,34,114.0631759475665);texture_31=spriteTexture('Badlands', yey); PieSprite(scene, texture_31,30,391.7454864528726,34,111.45380501148495);texture_32=spriteTexture('Loch Modan', yey); PieSprite(scene, texture_32,30,395.21550049260804,34,82.43017205334165);texture_33=spriteTexture('Dun Morogh', yey); PieSprite(scene, texture_33,30,337.29679068468414,44,87.79113862904887);texture_34=spriteTexture('Twilight Highlands', yey); PieSprite(scene, texture_34,30,432.5227454002263,28,60.76836375472595);texture_35=spriteTexture('Wetlands', yey); PieSprite(scene, texture_35,30,354.934918415537,24,43.181241103898316);texture_36=spriteTexture('Arathi Highlands', yey); PieSprite(scene, texture_36,30,379.83639451845283,24,13.520356001944405);texture_37=spriteTexture('The Hinterlands', yey); PieSprite(scene, texture_37,30,391.5695800872891,34,-12.908190028917076);texture_38=spriteTexture('Hillsbrad Foothills', yey); PieSprite(scene, texture_38,30,345.7407475978628,24,-1.890201373109902);texture_39=spriteTexture('Gilneas', yey); PieSprite(scene, texture_39,30,296.52793626675634,24,17.84908060196977);texture_40=spriteTexture('Silverpine Forest', yey); PieSprite(scene, texture_40,30,308.03288950112943,24,-18.1261526897862);texture_41=spriteTexture('Tirisfal Glades', yey); PieSprite(scene, texture_41,30,322.59503720083575,24,-51.44381451717823);texture_42=spriteTexture('Western Plaguelands', yey); PieSprite(scene, texture_42,30,357.5636429226708,30,-42.876969500513084);texture_43=spriteTexture('Eastern Plaguelands', yey); PieSprite(scene, texture_43,30,405.8146279931575,34,-57.98487867077536);      lol = false;

  }
  //let texture_0 = spriteTexture('Durotar',1)	
	//(scene, texture_0, 30, -277.78955311352763, 24, 38.672658110357710);
    console.log(scene.children.slice(4))
  
  console.log(textureUpdate())
  
  
  
  
  
	//window.addEventListener( 'click', onDocumentMouseOver, false ); 
const animate = () => {
  	//water.rotation.z -= 0.025;
   	//mesh.rotation.z -= 0.025;
  	if (lol == true){
      
      cubeX.onChange(function(value) 
	{   yey = value;   });
      //yey += 1;
      scene.remove.apply(scene, scene.children.slice(scene.children.length-44,(scene.children.length)));
          console.log(scene.children.slice(4))

   		console.log(lol);
      lol = false;
			//window['scene'] = scene; 
      //window['yey'] = yey; 
			// window.eval(crtZonesSprites())
			//texture_0=spriteTexture('Durotar', yey); PieSprite(scene, texture_0,30,-277.78955311352763,24,38.67265811035771);texture_1=spriteTexture('Azshara', yey); PieSprite(scene, texture_1,30,-236.90184905507408,24,-18.04310167920776);texture_2=spriteTexture('Northen Barrens', yey); PieSprite(scene, texture_2,30,-324.3342548486014,24,42.40533222353124);texture_3=spriteTexture('Southern Barrens', yey); PieSprite(scene, texture_3,30,-329.55571944397286,24,77.34899932128461);texture_4=spriteTexture('Mulgore', yey); PieSprite(scene, texture_4,30,-360.32731675044806,24,79.35111158362415);texture_5=spriteTexture('Ashenvale', yey); PieSprite(scene, texture_5,30,-343.5705344278353,24,6.189150329805115);texture_6=spriteTexture('Felwood', yey); PieSprite(scene, texture_6,30,-350.66999035361914,44,-64.92611869671175);texture_7=spriteTexture('Darkshore', yey); PieSprite(scene, texture_7,30,-385.31446419961196,24,-76.68302114072709);texture_8=spriteTexture('Winterspring', yey); PieSprite(scene, texture_8,30,-284.57397200584023,54,-81.47558729825629);texture_9=spriteTexture('Moonglade', yey); PieSprite(scene, texture_9,30,-321.13909336551916,48,-97.74738874506933);texture_10=spriteTexture('Teldrassil', yey); PieSprite(scene, texture_10,30,-402.9094076156481,78,-131.7407672265867);texture_11=spriteTexture('Mount Hyjal', yey); PieSprite(scene, texture_11,30,-307.3388799075823,94,-47.834504859241434);texture_12=spriteTexture('Stonetalon Mountains', yey); PieSprite(scene, texture_12,30,-399.0184945319111,30,20.7443401431147);texture_13=spriteTexture('Desolace', yey); PieSprite(scene, texture_13,30,-399.5848529640793,24,64.0883236559438);texture_14=spriteTexture('Dustwallow Marsh', yey); PieSprite(scene, texture_14,30,-287.0818159107408,24,120.27639521544074);texture_15=spriteTexture('Thousand Needles', yey); PieSprite(scene, texture_15,30,-289.78409117229796,30,157.76589871394427);texture_16=spriteTexture('Feralas', yey); PieSprite(scene, texture_16,30,-410.16130255590474,34,122.75078982610768);texture_17=spriteTexture('Silithus', yey); PieSprite(scene, texture_17,30,-388.9210583914758,24,180.21265329905296);texture_18=spriteTexture('UnGoro Crater', yey); PieSprite(scene, texture_18,30,-344.53177754459716,24,176.73378268582215);texture_19=spriteTexture('Tanaris', yey); PieSprite(scene, texture_19,30,-300.38527277906513,30,200.80222710443277);texture_20=spriteTexture('Uldum', yey); PieSprite(scene, texture_20,30,-364.4577852044935,38,234.19477795867547);texture_21=spriteTexture('The Cape of Stranglethorn', yey); PieSprite(scene, texture_21,30,320.40466464778575,24,238.1933703285855);texture_22=spriteTexture('Northern Stranglethorn', yey); PieSprite(scene, texture_22,30,328.4634388211147,24,204.69122514469524);texture_23=spriteTexture('Blasted Lands', yey); PieSprite(scene, texture_23,30,391.47520078921195,24,191.7275989959382);texture_24=spriteTexture('Swamp of Sorrows', yey); PieSprite(scene, texture_24,30,402.0329790005663,24,177.5969478535933);texture_25=spriteTexture('Duskwood', yey); PieSprite(scene, texture_25,30,336.8137692532394,30,176.69531634588702);texture_26=spriteTexture('Westfall', yey); PieSprite(scene, texture_26,30,295.8557533417584,24,178.16070679515727);texture_27=spriteTexture('Redridge Mountains', yey); PieSprite(scene, texture_27,30,386.95887400109643,30,157.47511444858765);texture_28=spriteTexture('Elwynn Forest', yey); PieSprite(scene, texture_28,30,333.4699859916333,24,164.0337620546048);texture_29=spriteTexture('Burning Steppes', yey); PieSprite(scene, texture_29,30,363.3163146357488,34,136.76694774590567);texture_30=spriteTexture('Searing Gorge', yey); PieSprite(scene, texture_30,30,355.61022578427736,34,114.0631759475665);texture_31=spriteTexture('Badlands', yey); PieSprite(scene, texture_31,30,391.7454864528726,34,111.45380501148495);texture_32=spriteTexture('Loch Modan', yey); PieSprite(scene, texture_32,30,395.21550049260804,34,82.43017205334165);texture_33=spriteTexture('Dun Morogh', yey); PieSprite(scene, texture_33,30,337.29679068468414,44,87.79113862904887);texture_34=spriteTexture('Twilight Highlands', yey); PieSprite(scene, texture_34,30,432.5227454002263,28,60.76836375472595);texture_35=spriteTexture('Wetlands', yey); PieSprite(scene, texture_35,30,354.934918415537,24,43.181241103898316);texture_36=spriteTexture('Arathi Highlands', yey); PieSprite(scene, texture_36,30,379.83639451845283,24,13.520356001944405);texture_37=spriteTexture('The Hinterlands', yey); PieSprite(scene, texture_37,30,391.5695800872891,34,-12.908190028917076);texture_38=spriteTexture('Hillsbrad Foothills', yey); PieSprite(scene, texture_38,30,345.7407475978628,24,-1.890201373109902);texture_39=spriteTexture('Gilneas', yey); PieSprite(scene, texture_39,30,296.52793626675634,24,17.84908060196977);texture_40=spriteTexture('Silverpine Forest', yey); PieSprite(scene, texture_40,30,308.03288950112943,24,-18.1261526897862);texture_41=spriteTexture('Tirisfal Glades', yey); PieSprite(scene, texture_41,30,322.59503720083575,24,-51.44381451717823);texture_42=spriteTexture('Western Plaguelands', yey); PieSprite(scene, texture_42,30,357.5636429226708,30,-42.876969500513084);texture_43=spriteTexture('Eastern Plaguelands', yey); PieSprite(scene, texture_43,30,405.8146279931575,34,-57.98487867077536);      lol = false;
    }

    eval(textureUpdate())

		 //texture_1.needsUpdate = true; texture_2.needsUpdate = true; texture_3.needsUpdate = true; texture_4.needsUpdate = true; texture_5.needsUpdate = true; texture_6.needsUpdate = true; texture_7.needsUpdate = true; texture_8.needsUpdate = true; texture_9.needsUpdate = true; texture_10.needsUpdate = true; texture_11.needsUpdate = true; texture_12.needsUpdate = true; texture_13.needsUpdate = true; texture_14.needsUpdate = true; texture_15.needsUpdate = true; texture_16.needsUpdate = true; texture_17.needsUpdate = true; texture_18.needsUpdate = true; texture_19.needsUpdate = true; texture_20.needsUpdate = true; texture_21.needsUpdate = true; texture_22.needsUpdate = true; texture_23.needsUpdate = true; texture_24.needsUpdate = true; texture_25.needsUpdate = true; texture_26.needsUpdate = true; texture_27.needsUpdate = true; texture_28.needsUpdate = true; texture_29.needsUpdate = true; texture_30.needsUpdate = true; texture_31.needsUpdate = true; texture_32.needsUpdate = true; texture_33.needsUpdate = true; texture_34.needsUpdate = true; texture_35.needsUpdate = true; texture_36.needsUpdate = true; texture_37.needsUpdate = true; texture_38.needsUpdate = true; texture_39.needsUpdate = true; texture_40.needsUpdate = true; texture_41.needsUpdate = true; texture_42.needsUpdate = true; texture_43.needsUpdate = true; 
    requestAnimationFrame(animate);
 		controls.update();
 
	  renderer.render(scene, camera);
};
  
  //dispose from memeory
//renderer.renderLists.dispose();
//mesh.geometry.dispose();
//mesh.material.dispose();
//scene.remove( mesh );

  
animate();
  })()